AGW Logo

svn SVN Revision 69620 For ultimatelistctrl

This file contains the SVN revision history for ultimatelistctrl, at revision 69620.

Available information include commit date, the name of the committer, the file size, the SVN log messages and a diff from the previous version (if available).


file_info File Information

  • Commit Date: 10-Dec-2009 18:09:38 UTC
  • Committer: AG
  • File Size: 457330 byte(s)

svn_log Log Messages

The following log message was entered by the committer:

  • UltimateListCtrl: fixed a few bugs and added a new demo (Windows7Explorer_Contents.py) showing an emulation of the Windows 7 Explorer behaviour when “Contents” is selected as a view;
  • AUI: Added a self._mgr.UnInit to the demo to no avail, wxPython still crashes with an assert.

svn_diff Diff To Previous Version (69347)

Version SVN diff:

--- wxPython/3rdParty/AGW/agw/ultimatelistctrl.py   2011/10/09 18:54:23     69347
+++ wxPython/3rdParty/AGW/agw/ultimatelistctrl.py   2011/10/31 21:11:23     69620
@@ -3,7 +3,7 @@
# Inspired by and heavily based on the wxWidgets C++ generic version of wxListCtrl.
#
# Andrea Gavana, @ 08 May 2009
# Latest Revision: 09 Oct 2011, 21.00 GMT
#
#
# TODO List
@@ -225,7 +225,7 @@

UltimateListCtrl is distributed under the wxPython license.

-Latest Revision: Andrea Gavana @ 09 Oct 2011, 21.00 GMT
+Latest Revision: Andrea Gavana @ 31 Oct 2011, 21.00 GMT

Version 0.8

@@ -4598,7 +4598,6 @@
dc.SetTextForeground(item.GetColour())
elif useVista and drawn:
dc.SetTextForeground(wx.BLACK)
-                        dc.SetFont(boldFont)

if item.IsHyperText():
dc.SetFont(self._owner.GetHyperTextFont())
@@ -10376,10 +10375,10 @@

if not func:
self.__func = None
-            self._lines.sort(self.OnCompareItems)
else:
self.__func = func
-            self._lines.sort(self.OnCompareItems)
+
+        self._lines.sort(self.OnCompareItems)

if self.IsShownOnScreen():
self._dirty = True
@@ -10862,7 +10861,7 @@

self._headerWin = UltimateListHeaderWindow(self, wx.ID_ANY, self._mainWin,
wx.Point(0, 0),
-                                                       wx.Size(self.GetClientSize().x, self._headerHeight),
+                                                       wx.DefaultSize,
wx.TAB_TRAVERSAL, isFooter=False)

# ----------------------------------------------------
@@ -10900,7 +10899,7 @@

self._footerWin = UltimateListHeaderWindow(self, wx.ID_ANY, self._mainWin,
wx.Point(0, 0),
-                                                       wx.Size(self.GetClientSize().x, self._footerHeight),
+                                                       wx.DefaultSize,
wx.TAB_TRAVERSAL, isFooter=True)

# ----------------------------------------------------
@@ -3,7 +3,7 @@
#
# Andrea Gavana, @ 08 May 2009
-# Latest Revision: 09 Oct 2011, 21.00 GMT
+# Latest Revision: 31 Oct 2011, 21.00 GMT
#
#
Tree